var index = async (options) => {
  const { minify, parseCss, preflight, root, watch, windiCssVersion, config } = Object.assign({
    minify: false,
    parseCss: true,
    preflight: true,
    root: document.body,
    watch: true,
    windiCssVersion: "latest"
  }, options);
  const [{ default: Processor }, { CSSParser }] = await Promise.all([
    import(
      /* @vite-ignore */
      `https://esm.run/windicss@${windiCssVersion}`
    ),
    import(
      /* @vite-ignore */
      `https://esm.run/windicss@${windiCssVersion}/utils/parser`
    )
  ]);
  const processor = new Processor(config);
  const styleSheet = processor.interpret().styleSheet;
  const styleElement = document.head.appendChild(document.createElement("style"));
  const classes = new Set(), queuedClasses = new Set();
  const tags = new Set(), queuedTags = new Set();
  const process = (element, recurse = true) => {
    const descendants = recurse ? element.querySelectorAll("*") : [];
    [element, ...descendants].forEach((elem) => {
      elem.classList.length > 0 && elem.classList.forEach((className) => {
        !classes.has(className) && queuedClasses.add(className);
      });
      if (preflight) {
        const tagName = elem.tagName.toLowerCase();
        !tags.has(tagName) && queuedTags.add(tagName);
      }
    });
  };
  const scheduleUpdate = (() => {
    const request = window.requestAnimationFrame || ((callback) => setTimeout(callback, 16.66));
    let id = 0;
    return () => !!(queuedClasses.size + queuedTags.size) && id == 0 && (id = request(() => {
      update();
      id = 0;
    }));
  })();
  const update = () => {
    if (queuedClasses.size) {
      const classString = [...queuedClasses].join(" ");
      const classStyleSheet = processor.interpret(classString).styleSheet;
      styleSheet.extend(classStyleSheet);
      queuedClasses.forEach((c) => classes.add(c));
      queuedClasses.clear();
    }
    if (preflight && queuedTags.size) {
      const html = [...queuedTags].map((t) => `<${t}`).join(" ");
      const preflightStyleSheet = processor.preflight(html);
      styleSheet.extend(preflightStyleSheet);
      queuedTags.forEach((t) => tags.add(t));
      queuedTags.clear();
    }
    styleSheet.sort();
    styleElement.innerHTML = styleSheet.build(minify);
  };
  const parseStyles = (element) => {
    element.querySelectorAll("style[lang='windify']").forEach((style) => {
      const cssParser = new CSSParser(style.textContent, processor);
      style.innerHTML = cssParser.parse().build();
      style.removeAttribute("lang");
    });
  };
  const init = async () => {
    if (parseCss) {
      parseStyles(document.documentElement);
    }
    process(root);
    update();
    [document.documentElement, document.body, root].forEach((elem) => {
      if (elem.hidden) {
        elem.removeAttribute("hidden");
      }
    });
    if (watch) {
      new MutationObserver((mutations) => {
        mutations.forEach(({ type, target, attributeName, addedNodes }) => {
          type === "attributes" && attributeName === "class" && process(target, false);
          type === "childList" && addedNodes.forEach((node) => node.nodeType === Node.ELEMENT_NODE && process(node));
        });
        scheduleUpdate();
      }).observe(root, {
        childList: true,
        subtree: true,
        attributeFilter: ["class"]
      });
    }
  };
  if (typeof window === "undefined") {
    console.warn("Windify cannot be used outside of a browser.");
    return;
  }
  await init();
  return async (...elements) => {
    elements.forEach((elem) => {
      parseCss && parseStyles(elem);
      process(elem);
    });
    scheduleUpdate();
  };
};
export { index as default };
